@@ -32,6 +32,8 @@ MainWindow::MainWindow(QWidget *parent)
     QProcess *myProcess = new QProcess();
     myProcess->start(program, arguments);
 
+    this->toPlaylist = false;
+
     connect(articleList, SIGNAL(articleSelected(QTableWidgetItem*)), this, SLOT(article_selected(QTableWidgetItem*)));
     connect(playlist, SIGNAL(articleSelected(QTreeWidgetItem*, int)), this, SLOT(playlist_item_selected(QTreeWidgetItem*, int)));
     connect(options, SIGNAL(closeButtonClicked()), this, SLOT(close()));
@@ -42,9 +44,10 @@ MainWindow::MainWindow(QWidget *parent)
     connect(articleList, SIGNAL(newSearch(QString)), this, SLOT(newSearch(QString)));
     connect(network, SIGNAL(articleContentReceived(QString,QString)), this, SLOT(openArticleInPlayer(QString,QString)));
     connect(articleList, SIGNAL(articleToPlaylist(QString,QString)), this, SLOT(addToPlaylist(QString,QString)));
-    connect(network, SIGNAL(playlistArticleSaved()), message, SLOT(hide()));
+    connect(network, SIGNAL(playlistArticleSaved(QString)), this, SLOT(articleSaved(QString)));
     connect(player, SIGNAL(openArticleFromLink(QListWidgetItem*)), this, SLOT(openArticleFromLink(QListWidgetItem*)));
-    connect(player, SIGNAL(audioCreated()), message, SLOT(hide()));
+    connect(player, SIGNAL(audioCreated()), this, SLOT(audioCreated()));
+    connect(player,SIGNAL(playListFileAdded()), this, SLOT(openPlaylistFiles()));
    // connect(network, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateProgressBar(qint64,qint64)));
 }
 
@@ -60,7 +63,7 @@ void MainWindow::setOrientation(ScreenOrientation orientation)
     // If the version of Qt on the device is < 4.7.2, that attribute won't work
     if (orientation != ScreenOrientationAuto) {
         const QStringList v = QString::fromAscii(qVersion()).split(QLatin1Char('.'));
-        if (v.count() == 3 && (v.at(0).toInt() << 16 | v.at(1).toInt() << 8 | v.at(2).toInt()) < 0x040702) {
+        if (v.count() == 3 && (v.at(0).toIntarticleCon() << 16 | v.at(1).toInt() << 8 | v.at(2).toInt()) < 0x040702) {
             qWarning("Screen orientation locking only supported with Qt 4.7.2 and above");
             return;
         }
@@ -137,7 +140,9 @@ void MainWindow::on_searchButton_clicked()
         network->searchKeyWord(this->ui->searchLineEdit->text());
         this->searchWord = this->ui->searchLineEdit->text();
         this->ui->label->hide();
-        this->ui->label_2->hide();
+        this->ui->label->setHidden(true);
+        this->ui->label_2->setHidden(true);
+        this->ui->searchLineEdit->clear();
     }
 }
 
@@ -147,6 +152,8 @@ void MainWindow::on_mainWindowButton_clicked()
     {
         ui->mainWindowButton->setDown(true);
         articleList->show();
+        this->ui->label->hide();
+        this->ui->label_2->hide();
     }
     else
     {
@@ -182,6 +189,8 @@ void MainWindow::on_playlistsButton_clicked()
     {
         playlist->show();
         ui->playlistsButton->setDown(true);
+        this->ui->label->hide();
+        this->ui->label_2->hide();
     }
     if (articleList->isVisible())
     {
@@ -209,6 +218,8 @@ void MainWindow::on_playerButton_clicked()
     {
         player->show();
         ui->playerButton->setDown(true);
+        this->ui->label->hide();
+        this->ui->label_2->hide();
     }
     if (articleList->isVisible())
     {
@@ -229,8 +240,9 @@ void MainWindow::on_playerButton_clicked()
 void MainWindow::article_selected(QTableWidgetItem *item)
 {
     message->setLabelText("Loading " + item->text());
+    QString stripped = item->text().toLower().remove(QRegExp("[^A-Za-z0-9]"));
     message->show();
-    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -240,7 +252,11 @@ void MainWindow::openArticleFromLink(QListWidgetItem *item)
         player->hide();
     message->setLabelText("Loading " + item->text());
     message->show();
-    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+
+    QString stripped = item->text().toLower().remove(QRegExp("[^A-Za-z0-9]"));
+
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+    qDebug()<<"openarticlefromlink"<<stripped<<existsAlready;
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -248,7 +264,9 @@ void MainWindow::playlist_item_selected(QTreeWidgetItem *item, int column)
 {
     message->setLabelText("Opening " + item->text(column));
     message->show();
-    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    QString stripped = item->text(column).toLower().remove(QRegExp("[^A-Za-z0-9]"));
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+
     network->retrieveArticle(item->text(column), existsAlready);
 }
 
@@ -262,6 +280,7 @@ void MainWindow::on_optionsButton_clicked()
 
 void MainWindow::addToPlaylistClicked()
 {
+    this->toPlaylist = true;
     QStringList list = playlist->getPlaylists();
 
     articleList->openSplashScreen(list);
@@ -269,19 +288,56 @@ void MainWindow::addToPlaylistClicked()
 
 void MainWindow::playlist_selected(QList<QTreeWidgetItem *> items, int column)
 {
-    player->clearCurrentArticles();
-    QTreeWidgetItem *item;
-    foreach (item, items)
-    {
-        openPlaylist = true;
-       /* if (item == items.first())
-            openPlaylist = false;
-        else
-            openPlaylist = true;*/
-        bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
-        network->retrieveArticle(item->text(column), existsAlready);
 
+    this->playlistList = items;
+    this->playlistColumn = column;
+    qDebug()<<"in main with playlistitems";
+    player->clearCurrentArticles();
+    openPlaylist = true;
+    int i = 0;
+    while (i<this->playlistList.count())
+    {
+        if(this->playlistList.count()>i)
+        {
+             QString stripped = this->playlistList.at(i)->text(column).toLower().remove(QRegExp("[^A-Za-z0-9]"));
+            bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+            qDebug()<<this->playlistList.at(i)->text(column)<<existsAlready;
+            network->retrieveArticle(this->playlistList.at(i)->text(column), existsAlready);
+
+        }
+        i++;
     }
+
+
+}
+
+void MainWindow::openPlaylistFiles()
+{
+    if (!this->playlistList.isEmpty())
+    {
+        if (this->playlistList.count() < 1)
+        {
+            if(!player->isVisible())
+                player->show();
+        }
+        else if (this->playlistList.count() == 1)
+        {
+            QString stripped = this->playlistList.takeFirst()->text(playlistColumn).toLower().remove(QRegExp("[^A-Za-z0-9]"));
+            bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+            qDebug()<<this->playlistList.takeFirst()->text(playlistColumn)<<existsAlready;
+            openPlaylist = false;
+            network->retrieveArticle(this->playlistList.takeFirst()->text(playlistColumn), existsAlready);
+        }
+        else
+        {
+            QString stripped = this->playlistList.takeFirst()->text(playlistColumn).toLower().remove(QRegExp("[^A-Za-z0-9]"));
+            openPlaylist = true;
+            bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+            qDebug()<<this->playlistList.takeFirst()->text(playlistColumn)<<existsAlready;
+            network->retrieveArticle(this->playlistList.takeFirst()->text(playlistColumn), existsAlready);
+        }
+    }
+    //TODO playlistat ei toimi
 }
 
 void MainWindow::openArticleList(QList<QString> searchTitles)
@@ -303,20 +359,29 @@ void MainWindow::newSearch(QString keyword)
 
 void MainWindow::openArticleInPlayer(QString title, QString article)
 {
-     message->setLabelText("Processing " + title);
-     player->openArticle(title, article, openPlaylist);
-     ui->playerButton->setDown(true);
-     ui->mainWindowButton->setDown(false);
 
 
-     if(!player->isVisible())
-        player->show();
+        qDebug()<<"open"<<title;
+         message->setLabelText("Processing " + title);
+         player->openArticle(title, article, openPlaylist);
+         ui->playerButton->setDown(true);
+         ui->mainWindowButton->setDown(false);
+
+
+         if (openPlaylist)
+         {
+             qDebug()<<openPlaylist;
+             openPlaylist = false;
+          //   player->setPlaylistFocus();
+         }
+         else
+         {
+             if(!player->isVisible())
+                player->show();
+         }
+
+
 
-     if (openPlaylist)
-     {
-         openPlaylist = false;
-         player->setPlaylistFocus();
-     }
 
 
      //message->hide();
@@ -324,12 +389,14 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
 
 void MainWindow::addToPlaylist(QString playlistname, QString item)
 {
+    qDebug()<<playlistname<<item;
     message->setLabelText("Saving");
     message->setParent(articleList);
     message->show();
-    network->retrieveArticle(item, false, true);
+    network->retrieveArticle(item, false, this->toPlaylist);
     playlist->addToPlaylist(playlistname, item);
     network->fileSaved(item);
+
 }
 
 /*void MainWindow::updateProgressBar(qint64 bytesReceived, qint64 bytesTotal)
@@ -368,3 +435,24 @@ void MainWindow::on_searchLineEdit_returnPressed()
         this->searchWord = this->ui->searchLineEdit->text();
     }
 }
+
+void MainWindow::audioCreated()
+{
+    if (!this->toPlaylist)
+        message->hide();
+    else
+    {
+        this->toPlaylist = false;
+      //  qDebug()<<"c"<<item;
+        message->hide();
+    }
+}
+
+void MainWindow::articleSaved(QString title)
+{
+    if (this->toPlaylist)
+    {
+        QString stripped = title.toLower().remove(QRegExp("[^A-Za-z0-9]"));
+        player->createAudioForPlaylist("/home/user/MyDocs/.audiowiki/" +  stripped+".txt");
+    }
+}
