@@ -36,11 +36,12 @@ private:
     DataHandler *dataHandler;
     int mode;
     bool onlySaveArticle;
+    QString article;
 
 signals:
     void searchTitlesReceived(QList<QString> titles);
     void articleContentReceived(QString title, QString content);
-    void playlistArticleSaved();
+    void playlistArticleSaved(QString title);
     void downloadProgress(qint64 received, qint64 total);
 
 };
