@@ -26,10 +26,14 @@ Player::~Player()
 
 void Player::openArticle(QString itemName, QString text, bool playlist)
 {
-    path = "/home/user/MyDocs/.audiowiki/" + itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
+    qDebug()<<"player"<<playlist;
+ //   if (playlist)
+   //     reload = true;
+    QString stripped = itemName.toLower().remove(QRegExp("[^A-Za-z0-9]"));
+    path = "/home/user/MyDocs/.audiowiki/" + stripped+".txt";
 
     QStringList links;
-    QFile *articleLinks = new QFile("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
+    QFile *articleLinks = new QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".dat");
     if (articleLinks->open(QIODevice::ReadOnly))
     {
         QDataStream out(articleLinks);   // we will serialize the data into the file
@@ -40,7 +44,8 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
     linkWidget = new LinkList(links, this);
     linkWidget->hide();
     connect(linkWidget, SIGNAL(linkClicked(QListWidgetItem*)), this, SLOT(linkListWidget_itemClicked(QListWidgetItem*)));
-
+    qDebug()<<"reload"<<reload;
+    bool audioExists = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".wav").exists();
     if (!reload)
     {
 
@@ -54,6 +59,10 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
         if (ui->playListWidget->count() > 1)
             ui->playListWidget->setCurrentRow(ui->playListWidget->count()-1);
 
+
+        qDebug()<<"audioExists"<<audioExists;
+
+
     }
     else
     {
@@ -63,12 +72,13 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
 
 
     ui->articleBrowser->setText(text);
-    bool audioExists = QFile("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav").exists();
-
-    if (!playlist || !audioExists)
+    if (!audioExists)
         audio->createWav(path);
-    if (audioExists)
-        audio->setAudio("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav");
+    else
+        audio->setAudio("/home/user/MyDocs/.audiowiki/" +  stripped +".wav");
+
+  /*  if (playlist)
+        this->playListFileAdded();*/
 
     articleLoaded = true;
 
@@ -166,3 +176,9 @@ void Player::wavCreated()
 {
     this->audioCreated();
 }
+
+void Player::createAudioForPlaylist(QString title)
+{
+    qDebug()<<"create in player audio"<<title;
+    audio->createWav(title);
+}
